# coding: utf-8

"""
Retrive Codema Fax Online
=====================

Command per la ricezione di fax dal servizio codemaonline_ ,
utilizzo:
python manage.py retrive_codema_fax.py

opzione -d : variabile Booleana per cancellare il messaggi una volta recuperati
opzione -l : variabile Numero per limitare il numero di messaggi recuperare
opzione -v : variabile Booleana per visualizzare i print

"""

import os, sys
from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.core.files.base import ContentFile
from django.core.files import File
import filecmp ,tempfile

from optparse import make_option
from jumbo.utils.functions import get_settings

from fax import settings
from fax.models import Fax, FaxNumber
from fax.codema import *

from django.contrib.auth.models import User

MAIL_BODY_RCV = """
Sender: %s
Sender Number: %s
Job ID: %s
Received Date: %s
Received Time: %s
Received Pages: %s
"""

class Command(BaseCommand):
    """Get all messages from configured Host
    """
    help = "Retrive Codema Fax."

    option_list = BaseCommand.option_list + (
        make_option('-d', '--delete-messages', dest='delete_messages', help='Delete Messages', default=False),
        make_option('-l', '--limit', dest='limit', help='Limit Messages', default=1000),
    )

    output_transaction = True

    def handle(self, **options):

        host,user,password = settings.FAX_CODEMA_HOST, settings.FAX_CODEMA_USER , settings.FAX_CODEMA_PASSWORD
        if settings.FAX_DEL_MESSAGES_ON_SERVER:
            options['delete_messages'] = 1

        messages ,pop_instance = get_messages(host,user,password, delete=options['delete_messages'], limit=options['limit'] )
        fax_retrived, fax_created = len(messages),0
        usr = User.objects.get(username='admin')

        for i in messages:
            codema_msg = CodemaMsg(i)
            if codema_msg.status == 'FAILED_SENT': continue
            info = codema_msg.info
            fax, created = Fax.objects.get_or_create(sender    = info['sender'],
                                                     date_sent = info['date_sent'],
                                                     status    = 2,
                                                     defaults=  {
                                                         'submitter': usr,
                                                         'subject': 'fax ricevuto ' + info['sender'] \
                                                                                    + ' :: ' +       \
                                                                                    info['subject_number'] },
                                                    )
            if created:
                fax_created += 1
                faxfile = codema_msg.attach_msg.get_filename()
                faxbuffer = ContentFile(codema_msg.attach)
                faxtemp = tempfile.NamedTemporaryFile(); faxtemp.write(codema_msg.attach); faxtemp.seek(0)
                filepath = os.path.join(settings.DOCUMENT_ROOT ,settings.FAX_PATH_DOCUMENTS + faxfile)
                # verifico l'esistenza o meno del file e confronto se i file sono gli stessi
                if os.path.exists(filepath):
                    if not filecmp.cmp( filepath,faxtemp.name):
                        fax.file.save(faxfile, faxbuffer)
                    else:
                        fax.file.save(faxfile, File(open(filepath)))
                else:
                    fax.file.save(faxfile, faxbuffer)


                # INVIO MAIL PER FAX RICEVUTI
                # Recupero gli indirizzi mail a cui dovranno essere spedite le notifiche
                # Creo un set in modo da non avere indirizzi mail duplicati
                data_fax = fax.date_last_modify.strftime('%d/%m/%Y %H:%M:%S')
                subject_fax = get_settings("fax.settings", "SUBJECT_FAX")
                from_fax = get_settings("fax.settings", "FROM_FAX")
                recipient_list = set()
                device_number = []
                try:
                    fax_numbers = FaxNumber.objects.filter(device__name = fax.device)
                    if fax_numbers:
                        device_number = fax_numbers[0]
                    else:# Da Guardare
                        device_number = FaxNumber.objects.all()[0]
                    for mail in device_number.notify_mails.split(","):
                        if mail:
                            recipient_list.add(mail.strip())
                except:
                    pass

                if device_number and device_number.send_at_received_fax and recipient_list:
                    mittente = ""
                    if fax.sender:
                        mittente += "%s" % (fax.sender,)
                    if fax.sender_number:
                        mittente += " - %s" % (fax.sender_number,)

                    subject = '%sReceived fax of %s from %s' % (subject_fax, data_fax, mittente)
                    from_email = 'Report Fax %s' % (from_fax,)
                    #hyla_mail_receipt = get_settings("fax.settings", "HYLA_MAIL_RECEIPT")
                    #recipient_list = hyla_mail_receipt.get(fax.device, [])
                    #if recipient_list:
                    body_message = MAIL_BODY_RCV % (fax.sender, fax.sender_number, fax.job, data_fax, fax.duration, fax.pages)

                    email = EmailMessage(subject, body_message, from_email, recipient_list)
                    email.attach_file(fax.file.path)
                    try:
                        email.send()
                    except Exception:
                        if options['verbosity'] == 2:
                            print "Email non inviata %s %s " % (fax.sender,fax.date_sent)
                        pass

        if options['verbosity'] == 2:
            print "Fax recuperati %s, Fax creati %d" % (fax_retrived,fax_created)

        pop_instance.quit()



